@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class ConfigurePluginsWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit ConfigurePluginsWidgetTest(QObject *parent = nullptr);
-    ~ConfigurePluginsWidgetTest();
+    ~ConfigurePluginsWidgetTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
