@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CONFIGUREPLUGINSLISTWIDGET_H
-#define CONFIGUREPLUGINSLISTWIDGET_H
+#pragma once
 
 #include "pimcommon_export.h"
 #include <PimCommon/PluginUtil>
@@ -14,6 +13,7 @@
 #include <QTreeWidgetItem>
 class QTreeWidget;
 class QAction;
+class KTreeWidgetSearchLineWidget;
 namespace PimCommon
 {
 /**
@@ -46,19 +46,16 @@ protected:
     class PluginItem : public QTreeWidgetItem
     {
     public:
-        PluginItem(QTreeWidgetItem *parent)
+        explicit PluginItem(QTreeWidgetItem *parent)
             : QTreeWidgetItem(parent)
-            , mEnableByDefault(false)
-            , mHasConfigureSupport(false)
-            , mEnableFromUserSettings(false)
         {
         }
 
         QString mIdentifier;
         QString mDescription;
-        bool mEnableByDefault;
-        bool mHasConfigureSupport;
-        bool mEnableFromUserSettings;
+        bool mEnableByDefault = false;
+        bool mHasConfigureSupport = false;
+        bool mEnableFromUserSettings = false;
     };
     void savePlugins(const QString &groupName, const QString &prefixSettingKey, const QVector<PluginItem *> &listItems);
     void fillTopItems(const QVector<PimCommon::PluginUtilData> &lst,
@@ -71,12 +68,12 @@ protected:
     void resetToUserSettings(const QVector<PluginItem *> &items);
     void changeState(const QVector<PluginItem *> &items);
 
-    QTreeWidget *mListWidget = nullptr;
+    QTreeWidget *const mListWidget;
 
 private:
+    KTreeWidgetSearchLineWidget *mTreeWidgetSearchLineEdit = nullptr;
     void slotConfigureClicked(QAction *act);
     bool mInitializeDone = false;
 };
 }
 
-#endif // CONFIGUREPLUGINSLISTWIDGET_H
