@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class LogActivitiesWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit LogActivitiesWidgetTest(QObject *parent = nullptr);
-    ~LogActivitiesWidgetTest();
+    ~LogActivitiesWidgetTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
