@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef LINEEDITWITHCOMPLETERNGTEST_H
-#define LINEEDITWITHCOMPLETERNGTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldClearCompleter();
 };
 
-#endif // LINEEDITWITHCOMPLETERNGTEST_H
