@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TEST_CUSTOMTOOLSWIDGETNG_GUI_H
-#define TEST_CUSTOMTOOLSWIDGETNG_GUI_H
+#pragma once
 
 #include <QWidget>
 namespace PimCommon
@@ -18,10 +17,9 @@ class CustomToolWidgetNgTest : public QWidget
     Q_OBJECT
 public:
     explicit CustomToolWidgetNgTest(QWidget *parent = nullptr);
-    ~CustomToolWidgetNgTest();
+    ~CustomToolWidgetNgTest() override;
 
 private:
     PimCommon::CustomToolsWidgetNg *mCustomTools;
 };
 
-#endif
