@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef BALOOCOMPLETIONEMAIL_H
-#define BALOOCOMPLETIONEMAIL_H
+#pragma once
 #include "pimcommonakonadi_private_export.h"
 #include <QStringList>
 namespace PimCommon
@@ -30,4 +29,3 @@ private:
 };
 }
 
-#endif // BALOOCOMPLETIONEMAIL_H
