@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -14,7 +14,7 @@ class BlackListBalooEmailUtilTest : public QObject
     Q_OBJECT
 public:
     explicit BlackListBalooEmailUtilTest(QObject *parent = nullptr);
-    ~BlackListBalooEmailUtilTest();
+    ~BlackListBalooEmailUtilTest() override;
 private Q_SLOTS:
     void shouldReturnEmptyResult();
     void shouldDontChangeWhenNotChanged();
